#!/usr/bin/env bash

set -o errexit
set -o nounset
set -o pipefail

function main()
{
	update_config_files
	load_service
}

function update_config_files()
{
	echo "Updating configuration files"

	declare -r conf_dir="/usr/local/etc/zabbix"
	declare -ar conf_files=(
		"${conf_dir}/zabbix_agentd.conf"
		"${conf_dir}/zabbix_agentd/userparameter_examples.conf"
		"${conf_dir}/zabbix_agentd/userparameter_mysql.conf"
	)

	for file in ${conf_files[@]}; do
		declare file_new="${file}.NEW"

		if [[ ! -f $file_new ]]; then
			echo "File '${file_new}' does not exist. Please report it to Zabbix Team."
			continue
		fi

		if [[ -f $file ]]; then
			echo "File '${file}' already exists"

			if cmp --silent "${file_new}" "${file}"; then
				unlink "${file_new}"
			else
				echo "Configuration file '${file_new}' has new and/or modified entries. Please update '${file}' manually if needed."
			fi
		else
			echo "File '${file}' did not exist, created new configuration file"
			mv "${file_new}" "${file}"
		fi
	done
}

function load_service()
{
	declare -r service="com.zabbix.zabbix_agentd"

	echo "Checking if service is loaded"

	if launchctl list | grep -q "${service}"; then
		echo "Restarting service"
		launchctl stop "${service}"
		launchctl start "${service}"
	else
		echo "Loading and starting service"
		launchctl load -w "/Library/LaunchDaemons/com.zabbix.zabbix_agentd.plist"
	fi
}

main "$@"
